/*
-------------------------------------------------------------------------------

Name: TB_MassRename.js

Description: This script is useful for selecting which layers you want to rename across multiple panels.

Usage: Select panels, then pick the layers you want to rename for each panel. When finished selecting, input your new layer name and hit OK!

Author: Corey Barnes and Karl Olson

Created: 2018/11/19

Updated: 2019/05/12

Version: 1.2.0

Social Media Info:
Corey on Twitter - http://twitter.com/myanimewaifu
Karl on Twitter - http://twitter.com/karlrolson

Contact Email: livingfruitvirus@gmail.com

-------------------------------------------------------------------------------
*/

function TB_Mass_Rename() {
  var selMgr = new SelectionManager;
  var layMgr = new LayerManager;
  var renameDialog = new Dialog;
  var textInput = new LineEdit;

  renameDialog.title = "New Layer Name";
  renameDialog.width = 200;
  renameDialog.add(textInput);

  var rd = renameDialog.exec();

  // If dialog cancelled, return
  if (!rd) {
    return;
  }

  var panelSel = selMgr.getPanelSelection();
  if (panelSel.length <= 0) return;

  // Begin the repeating process of checking off layers in each of the selected panels.

  var pattern = new Array(0);
  var allNames = {};

  for (var m = 0; m < panelSel.length; ++m) {
    // Create a list of all layer names in the selected panels
    var layerNames = new Array(0);
    var panelId = panelSel[m];
    var numberOfLayers = layMgr.numberOfLayers(panelId);

     selMgr.setCurrentPanel(panelId); // This line of code moves the playhead to the panel whose layers are being displayed

    for (var j = 0; j < numberOfLayers; ++j) {
      var layerName = layMgr.layerName(panelId, j);
      layerNames.push(layerName);
      allNames[layerName] = true;
    }

    // Create a dialog displaying all layer names as checkboxes.
    d = new Dialog;
    d.title = "Mass Layer Rename";
    d.cancelButtonText = "Skip";
    d.width = 200;

    var group = new GroupBox;
    group.title = "Select layer to rename.";
    var count = 0;
    var radioButtonsArray = new Array(0);

    for (var i = 0; i < layerNames.length; ++i) {
      var c = new RadioButton;
      c.text = layerNames[i];

      if (count == 0) {
        c.checked = true;
      }
      count++;
      radioButtonsArray.push(c);
      group.add(c);
    }
   // BEGIN Update
    var bailOutButton = new GroupBox;
    var bailOutArray = new Array(0);
    var c2 = new CheckBox;

    c2.text = "Check this box and hit OK to abort script.";
    bailOutArray.push(c2);
    bailOutButton.add(c2)
   // END Update
    d.add(group);
    d.add(bailOutButton); // Update

    var rc = d.exec();

    if (rc) {
	if (c2.checked === true) {
	
	  var abortMessage = 'Script aborted.';
	  MessageBox.information(abortMessage);
	  return;

	} else {

      for (var f = 0; f < count; f++) {
        var r = radioButtonsArray[f];
        if (r.checked === true) {
          pattern.push(f);
          break;
	  }
        }
      }
    } else {
      // dialog skipped, add a blank space in the array
      pattern.push(null);
    }

  } // End of selection loop

  // Start renaming each layer

  scene.beginUndoRedoAccum('Mass Layer Rename');

  for (var n = 0; n < panelSel.length; n++) {
    if (pattern[n] !== null) {
      var panelId = panelSel[n];
      var numberOfLayers = layMgr.numberOfLayers(panelId);
      for (var j = 0; j < numberOfLayers; j++) {
        var layerName = layMgr.layerName(panelId, j);
        if (j !== pattern[n] && layerName === textInput.text) {
          layMgr.renameLayer(panelSel[n], j, layerName + '_0');
        }
      }
      layMgr.renameLayer(panelSel[n], pattern[n], textInput.text);
    }
  }

  scene.endUndoRedoAccum();

  // Prepare final message.
  var finalMessage = 'Layers successfully renamed.';
  MessageBox.information(finalMessage);

} // End of Function